# eric7.QScintilla.Lexers.LexerPO

Module implementing a Gettext lexer with some additional methods.

### Global Attributes

None

### Classes

LexerPO | Subclass to implement some additional lexer dependant methods.

### Functions

createLexer | Function to instantiate a lexer object.

## LexerPO

Subclass to implement some additional lexer dependant methods.

### Derived from

Lexer, QsciLexerPO

### Class Attributes

None

### Class Methods

None

### Methods

LexerPO | Constructor
defaultKeywords | Public method to get the default keywords.
initProperties | Public slot to initialize the properties.
isCommentStyle | Public method to check, if a style is a comment style.
isStringStyle | Public method to check, if a style is a string style.

### Static Methods

None

#### LexerPO (Constructor)

LexerPO(parent=None)

Constructor

parent (QWidget)
  parent widget of this lexer

#### LexerPO.defaultKeywords

defaultKeywords(kwSet)

Public method to get the default keywords.

kwSet (int)
  number of the keyword set

Return:
  string giving the keywords or None

Return Type:
  str

#### LexerPO.initProperties

initProperties()

Public slot to initialize the properties.

#### LexerPO.isCommentStyle

isCommentStyle(style)

Public method to check, if a style is a comment style.

style (int)
  style to check

Return:
  flag indicating a comment style

Return Type:
  bool

#### LexerPO.isStringStyle

isStringStyle(style)

Public method to check, if a style is a string style.

style (int)
  style to check

Return:
  flag indicating a string style

Return Type:
  bool

Up

## createLexer

createLexer(variant, parent=None)

Function to instantiate a lexer object.

variant (str)
  name of the language variant (unused)
parent (QObject)
  parent widget of this lexer

Return:
  instantiated lexer object

Return Type:
  LexerPO

Up